@@ -1,12 +1,12 @@
 #' @rdname pcoa.sig
 #' @encoding UTF-8
 #' @export
-print.pcoasig<-function(x , ...){
+print.pcoasig <- function(x, ...){
 	cat("Call:\n")
 	cat(deparse(x$call), "\n\n")
 	cat("PCoA values:\n")
-	print(as.matrix(x$PCoA$values))
+	print(x$values)
 	cat("\nProbabilities:\n")
-	print(as.matrix(x$probabilities))
+	print(x$probabilities)
 	invisible(x)
 }
\ No newline at end of file
